@@ -28,7 +28,8 @@ class Angebot(Geschaeftsobjekt):
     werden.
 
     .. HINT::
-        `Angebot JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/AngebotSchema.json>`_
+        `Angebot JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/AngebotSchema.json>`_
+
     """
 
     bo_typ: BoTyp = attr.ib(default=BoTyp.ANGEBOT)
