@@ -26,7 +26,8 @@ class Ausschreibung(Geschaeftsobjekt):
     Das BO Ausschreibung dient zur detaillierten Darstellung von ausgeschriebenen Energiemengen in der Energiewirtschaft
 
     .. HINT::
-        `Ausschreibung JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/AusschreibungSchema.json>`_
+        `Ausschreibung JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/AusschreibungSchema.json>`_
+
     """
 
     # required attributes
