@@ -22,7 +22,8 @@ class Energiemenge(Geschaeftsobjekt):
     Abbildung von Mengen, die Lokationen zugeordnet sind
 
     .. HINT::
-        `Energiemenge JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/EnergiemengeSchema.json>`_
+        `Energiemenge JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/EnergiemengeSchema.json>`_
+
     """
 
     # required attributes
