@@ -24,7 +24,7 @@ class Kosten(Geschaeftsobjekt):
     Die Kosten werden dabei in Kostenblöcke und diese wiederum in Kostenpositionen strukturiert.
 
     .. HINT::
-        `Kosten JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/KostenSchema.json>`_"
+        `Kosten JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/KostenSchema.json>`_"
 
     """
 
