@@ -31,7 +31,8 @@ class Marktlokation(Geschaeftsobjekt):
     Object containing information about a Marktlokation
 
     .. HINT::
-        `Marktlokation JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/MarktlokationSchema.json>`_
+        `Marktlokation JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/MarktlokationSchema.json>`_
+
     """
 
     # required attributes
