@@ -38,7 +38,8 @@ class Messlokation(Geschaeftsobjekt):
     Object containing information about a Messlokation
 
     .. HINT::
-        `Messlokation JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/MesslokationSchema.json>`_
+        `Messlokation JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/MesslokationSchema.json>`_
+
     """
 
     # pylint: disable=unused-argument, no-self-use
