@@ -21,7 +21,8 @@ class Netznutzungsrechnung(Rechnung):
     Modell für die Abbildung von Netznutzungsrechnungen
 
     .. HINT::
-        `Netznutzungsrechnung JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/NetznutzungsrechnungSchema.json>`_
+        `Netznutzungsrechnung JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/NetznutzungsrechnungSchema.json>`_
+
     """
 
     # required attributes
