@@ -21,7 +21,8 @@ class PreisblattDienstleistung(Preisblatt):
     Variante des Preisblattmodells zur Abbildung der Preise für wahlfreie Dienstleistungen
 
     .. HINT::
-        `PreisblattDienstleistung JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/PreisblattDienstleistungSchema.json>`_
+        `PreisblattDienstleistung JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/PreisblattDienstleistungSchema.json>`_
+
     """
 
     bo_typ: BoTyp = attr.ib(default=BoTyp.PREISBLATTDIENSTLEISTUNG)
