@@ -22,7 +22,8 @@ class PreisblattMessung(Preisblatt):
     Variante des Preisblattmodells zur Abbildung der Preise des Messstellenbetriebs und damit verbundener Leistungen
 
     .. HINT::
-        `PreisblattMessung JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/PreisblattMessungSchema.json>`_
+        `PreisblattMessung JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/PreisblattMessungSchema.json>`_
+
     """
 
     bo_typ: BoTyp = attr.ib(default=BoTyp.PREISBLATTMESSUNG)
