@@ -19,7 +19,8 @@ class PreisblattNetznutzung(Preisblatt):
     Die Variante des Preisblattmodells zur Abbildung der Netznutzungspreise
 
     .. HINT::
-        `PreisblattNetznutzung JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/PreisblattNetznutzungSchema.json>`_
+        `PreisblattNetznutzung JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/PreisblattNetznutzungSchema.json>`_
+
     """
 
     bo_typ: BoTyp = attr.ib(default=BoTyp.PREISBLATTNETZNUTZUNG)
