@@ -19,7 +19,8 @@ class Region(Geschaeftsobjekt):
     Modellierung einer Region als Menge von Kriterien, die eine Region beschreiben
 
     .. HINT::
-        `Region JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/RegionSchema.json>`_
+        `Region JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/RegionSchema.json>`_
+
     """
 
     # required attributes
