@@ -22,7 +22,8 @@ class Standorteigenschaften(Geschaeftsobjekt):
     Modelliert die regionalen und spartenspezifischen Eigenschaften einer gegebenen Adresse.
 
     .. HINT::
-        `Standorteigenschaften JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/StandorteigenschaftenSchema.json>`_
+        `Standorteigenschaften JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/StandorteigenschaftenSchema.json>`_
+
     """
 
     # required attributes
