@@ -17,7 +17,8 @@ class Tarifkosten(Tarifinfo):
     Objekt zur Kommunikation von Kosten, die im Rahmen der Tarifanwendung entstehen
 
     .. HINT::
-        `Tarifkosten JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/TarifkostenSchema.json>`_
+        `Tarifkosten JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/TarifkostenSchema.json>`_
+
     """
 
     # required attributes
