@@ -24,7 +24,8 @@ class Tarifpreisblatt(Tarifinfo):
     Tarifinformation mit Preisen, Aufschlägen und Berechnungssystematik
 
     .. HINT::
-        `Tarifpreisblatt JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/TarifpreisblattSchema.json>`_
+        `Tarifpreisblatt JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/TarifpreisblattSchema.json>`_
+
     """
 
     bo_typ: BoTyp = attr.ib(default=BoTyp.TARIFPREISBLATT)
