@@ -37,7 +37,8 @@ class Vertrag(Geschaeftsobjekt):
     Das Objekt dient dazu, alle Arten von Verträgen, die in der Energiewirtschaft Verwendung finden, abzubilden.
 
     .. HINT::
-        `Vertrag JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/VertragSchema.json>`_
+        `Vertrag JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/bo/VertragSchema.json>`_
+
     """
 
     # required attributes
