@@ -33,7 +33,8 @@ class Adresse(COM):
     Contains an address that can be used for most purposes.
 
     .. HINT::
-        `Adresse JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/AdresseSchema.json>`_
+        `Adresse JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/AdresseSchema.json>`_
+
     """
 
     # required attributes
