@@ -26,7 +26,8 @@ class AufAbschlag(COM):
     die individuell zu einem neuen oder bestehenden Liefervertrag abgeschlossen wurden.
 
     .. HINT::
-        `AufAbschlag JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/AufAbschlagSchema.json>`_
+        `AufAbschlag JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/AufAbschlagSchema.json>`_
+
     """
 
     # required attributes
