@@ -20,7 +20,7 @@ class Fremdkostenblock(COM):
     Komponente zur Abbildung eines Kostenblocks in den Fremdkosten
 
     .. HINT::
-        `Fremdkostenblock JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/FremdkostenblockSchema.json>`_
+        `Fremdkostenblock JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/FremdkostenblockSchema.json>`_
 
     """
 
