@@ -18,7 +18,8 @@ class Hardware(COM):
     Abbildung einer abrechenbaren Hardware.
 
     .. HINT::
-        `Hardware JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/HardwareSchema.json>`_
+        `Hardware JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/HardwareSchema.json>`_
+
     """
 
     # required attributes
