@@ -15,7 +15,8 @@ class Katasteradresse(COM):
     Dient der Adressierung über die Liegenschafts-Information.
 
     .. HINT::
-        `Katasteradresse JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/KatasteradresseSchema.json>`_
+        `Katasteradresse JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/KatasteradresseSchema.json>`_
+
     """
 
     gemarkung_flur: str
