@@ -19,7 +19,8 @@ class KriteriumWert(COM):
     Mit dieser Komponente können Kriterien und deren Werte definiert werden
 
     .. HINT::
-        `KriteriumWert JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/KriteriumWertSchema.json>`_
+        `KriteriumWert JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/KriteriumWertSchema.json>`_
+
     """
 
     # required attributes
