@@ -20,7 +20,8 @@ class Menge(COM):
     Abbildung einer Menge mit Wert und Einheit.
 
     .. HINT::
-        `Menge JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/MengeSchema.json>`_
+        `Menge JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/MengeSchema.json>`_
+
     """
 
     # required attributes
