@@ -22,7 +22,8 @@ class PositionsAufAbschlag(COM):
     Es können mehrere Auf-/Abschläge gleichzeitig ausgewählt werden.
 
     .. HINT::
-        `PositionsAufAbschlag JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/PositionsAufAbschlagSchema.json>`_
+        `PositionsAufAbschlag JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/PositionsAufAbschlagSchema.json>`_
+
     """
 
     # required attributes
