@@ -27,7 +27,8 @@ class Rechnungsposition(COM):
     In einem Rechnungsteil wird jeweils eine in sich geschlossene Leistung abgerechnet.
 
     .. HINT::
-        `Rechnungsposition JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/RechnungspositionSchema.json>`_
+        `Rechnungsposition JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/RechnungspositionSchema.json>`_
+
     """
 
     # required attributes
