@@ -17,7 +17,8 @@ class RegionalePreisgarantie(Preisgarantie):
     Abbildung einer Preisgarantie mit regionaler Abgrenzung
 
     .. HINT::
-        `RegionalePreisgarantie JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/RegionalePreisgarantieSchema.json>`_
+        `RegionalePreisgarantie JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/RegionalePreisgarantieSchema.json>`_
+
     """
 
     # required attributes
