@@ -31,7 +31,8 @@ class RegionalerAufAbschlag(COM):
     oder Abschlags ergeben.
 
     .. HINT::
-        `RegionalerAufAbschlag JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/RegionalerAufAbschlagSchema.json>`_
+        `RegionalerAufAbschlag JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/RegionalerAufAbschlagSchema.json>`_
+
     """
 
     # required attributes
