@@ -17,7 +17,8 @@ class Rufnummer(COM):
     Contains information to call or fax someone
 
     .. HINT::
-        `Rufnummer JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/RufnummerSchema.json>`_
+        `Rufnummer JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/RufnummerSchema.json>`_
+
     """
 
     # required attributes
