@@ -19,7 +19,8 @@ class StandorteigenschaftenGas(COM):
     Standorteigenschaften der Sparte Gas
 
     .. HINT::
-        `StandorteigenschaftenGas JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/StandorteigenschaftenGasSchema.json>`_
+        `StandorteigenschaftenGas JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/StandorteigenschaftenGasSchema.json>`_
+
     """
 
     # required attributes
