@@ -17,7 +17,8 @@ class Unterschrift(COM):
     Modellierung einer Unterschrift, z.B. für Verträge, Angebote etc.
 
     .. HINT::
-        `Unterschrift JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/UnterschriftSchema.json>`_
+        `Unterschrift JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/UnterschriftSchema.json>`_
+
     """
 
     # required attributes
