@@ -22,7 +22,8 @@ class Verbrauch(COM):
     Abbildung eines zeitlich abgegrenzten Verbrauchs
 
     .. HINT::
-        `Verbrauch JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/VerbrauchSchema.json>`_
+        `Verbrauch JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/VerbrauchSchema.json>`_
+
     """
 
     # required attributes
