@@ -20,10 +20,8 @@ def time_range_possibilities(instance, attribute, value):
     """
     An address is valid if it contains a postfach XOR (a strasse AND hausnummer).
     This functions checks for these conditions of a valid address.
-
-    .. HINT::
-        `Zeitraum JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/ZeitraumSchema.json>`_
     """
+
     if (
         instance.einheit
         and instance.dauer
@@ -62,6 +60,10 @@ class Zeitraum(COM):
     - Einheit und Dauer oder
     - Zeitraum: Startdatum bis Enddatum oder
     - Zeitraum: Startzeitpunkt (Datum und Uhrzeit) bis Endzeitpunkt (Datum und Uhrzeit)
+
+    .. HINT::
+        `Zeitraum JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/ZeitraumSchema.json>`_
+
     """
 
     # optional attributes
