@@ -18,7 +18,8 @@ class Zustaendigkeit(COM):
     Enthält die zeitliche Zuordnung eines Ansprechpartners zu Abteilungen und Zuständigkeiten.
 
     .. HINT::
-        `Zustaendigkeit JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/master/json_schemas/bo/ZustaendigkeitSchema.json>`_
+        `Zustaendigkeit JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/ZustaendigkeitSchema.json>`_
+
     """
 
     # required attributes
